==> coreboot_24.08+dfsg.orig.tar.xz: coreboot-24.08/Documentation/releases/index.md <==
# Release notes

## Upcoming release

Please add to the release notes as changes are added:
```{toctree}
:maxdepth: 1

24.11 - November 2024 <coreboot-24.11-relnotes.md>
```

The [checklist] contains instructions to ensure that a release covers all
important things and provides a reliable format for tarballs, branch
names etc.

For release related communications consider using a [template] so everything
important is taken care of.


## Previous releases

```{toctree}
:maxdepth: 1

24.08  - August 2024 <coreboot-24.08-relnotes.md>
24.05  - May 2024 <coreboot-24.05-relnotes.md>
24.02  - February 2024 <coreboot-24.02-relnotes.md>
4.22   - November 2023 <coreboot-4.22-relnotes.md>
4.21   - August 2023 <coreboot-4.21-relnotes.md>
4.20.1 - May 2023 <coreboot-4.20.1-relnotes.md>
4.19   - January 2023 <coreboot-4.19-relnotes.md>
4.18   - October 2022 <coreboot-4.18-relnotes.md>
4.17   - May 2022 <coreboot-4.17-relnotes.md>
4.16   - February 2022 <coreboot-4.16-relnotes.md>
4.15   - November 2021 <coreboot-4.15-relnotes.md>
4.14   - May 2021 <coreboot-4.14-relnotes.md>
4.13   - November 2020 <coreboot-4.13-relnotes.md>
4.12   - May 2020 <coreboot-4.12-relnotes.md>
4.11   - November 2019 <coreboot-4.11-relnotes.md>
4.10   - July 2019 <coreboot-4.10-relnotes.md>
4.9    - December 2018 <coreboot-4.9-relnotes.md>
4.8.1  - May 2018 <coreboot-4.8.1-relnotes.md>
4.7    - January 2018 <coreboot-4.7-relnotes.md>
4.6    - April 2017 <coreboot-4.6-relnotes.md>
4.5    - October 2016 <coreboot-4.5-relnotes.md>
4.4    - May 2016 <coreboot-4.4-relnotes.md>
4.3    - January 2016 <coreboot-4.3-relnotes.md>
4.2    - October 2015 <coreboot-4.2-relnotes.md>
4.1    - July 2015 <coreboot-4.1-relnotes.md>
```


[checklist]: checklist.md
[template]: templates.md

==> coreboot_24.12+dfsg.orig.tar.xz: coreboot-24.12/Documentation/releases/index.md <==
# Release notes

## Upcoming release

Please add to the release notes as changes are added:
```{toctree}
:maxdepth: 1

24.12 - December 2024 <coreboot-24.12-relnotes.md>
```

The [checklist] contains instructions to ensure that a release covers all
important things and provides a reliable format for tarballs, branch
names etc.

For release related communications consider using a [template] so everything
important is taken care of.


## Previous releases

```{toctree}
:maxdepth: 1

24.08  - August 2024 <coreboot-24.08-relnotes.md>
24.05  - May 2024 <coreboot-24.05-relnotes.md>
24.02  - February 2024 <coreboot-24.02-relnotes.md>
4.22   - November 2023 <coreboot-4.22-relnotes.md>
4.21   - August 2023 <coreboot-4.21-relnotes.md>
4.20.1 - May 2023 <coreboot-4.20.1-relnotes.md>
4.19   - January 2023 <coreboot-4.19-relnotes.md>
4.18   - October 2022 <coreboot-4.18-relnotes.md>
4.17   - May 2022 <coreboot-4.17-relnotes.md>
4.16   - February 2022 <coreboot-4.16-relnotes.md>
4.15   - November 2021 <coreboot-4.15-relnotes.md>
4.14   - May 2021 <coreboot-4.14-relnotes.md>
4.13   - November 2020 <coreboot-4.13-relnotes.md>
4.12   - May 2020 <coreboot-4.12-relnotes.md>
4.11   - November 2019 <coreboot-4.11-relnotes.md>
4.10   - July 2019 <coreboot-4.10-relnotes.md>
4.9    - December 2018 <coreboot-4.9-relnotes.md>
4.8.1  - May 2018 <coreboot-4.8.1-relnotes.md>
4.7    - January 2018 <coreboot-4.7-relnotes.md>
4.6    - April 2017 <coreboot-4.6-relnotes.md>
4.5    - October 2016 <coreboot-4.5-relnotes.md>
4.4    - May 2016 <coreboot-4.4-relnotes.md>
4.3    - January 2016 <coreboot-4.3-relnotes.md>
4.2    - October 2015 <coreboot-4.2-relnotes.md>
4.1    - July 2015 <coreboot-4.1-relnotes.md>
```


[checklist]: checklist.md
[template]: templates.md
